cijoe: tools for systems development and testing
================================================

.. image:: https://travis-ci.com/refenv/cijoe.svg?branch=master
   :target: https://travis-ci.com/refenv/cijoe
   :alt: Build Status

.. image:: https://readthedocs.org/projects/cijoe/badge/?version=latest
   :target: https://cijoe.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/cijoe.svg
   :target: https://pypi.org/project/cijoe
   :alt: PyPI

Tools for systems development and testing.

Please take a look at the documentation for how to install and use ``cijoe``:

* `Quickstart Guide`_
* `Installation`_
* `Usage`_

If you find bugs or need help then feel free to submit an `Issue`_. If you want
to get involved head over to the `GitHub page`_ to get the source code and
submit a `Pull request`_ with your changes.

.. _Quickstart Guide: https://cijoe.readthedocs.io/en/latest/quickstart.html
.. _Installation: https://cijoe.readthedocs.io/
.. _Usage: https://cijoe.readthedocs.io/
.. _GitHub page: https://github.com/refenv/cijoe
.. _Pull request: https://github.com/refenv/cijoe/pulls
.. _Issue: https://github.com/refenv/cijoe/issues
